@@ -2,6 +2,7 @@
 
 from __future__ import annotations
 
+from itertools import chain
 from textwrap import indent
 from xml.etree.ElementTree import Element
 
@@ -128,28 +129,26 @@ class _IdPrependingTreeprocessor(Treeprocessor):
 
 
 def _mimic(md: Markdown) -> Markdown:
+    md = getattr(md, "_original_md", md)
     new_md = Markdown()  # noqa: WPS442
-    new_md.registerExtensions(md.registeredExtensions + ["tables", "md_in_html"], {})
+    extensions = list(chain(md.registeredExtensions, ["tables", "md_in_html"]))
+    new_md.registerExtensions(extensions, {})
     new_md.treeprocessors.register(
         _IdPrependingTreeprocessor(md, ""),
         _IdPrependingTreeprocessor.name,
         priority=4,  # right after 'toc' (needed because that extension adds ids to headers)
     )
+    new_md._original_md = md  # type: ignore[attr-defined]  # noqa: WPS437
     return new_md
 
 
-class _MarkdownConverter:
+class MarkdownConverter:
     """Helper class to avoid breaking the original Markdown instance state."""
 
-    def __init__(self) -> None:  # noqa: D107
-        self._md_ref: Markdown = None  # type: ignore[assignment]
-        self._md_stack: list[Markdown] = []
-        self._counter: int = 0
-        self._level: int = 0
+    counter: int = 0
 
-    def setup(self, md: Markdown) -> None:
-        if not self._md_ref:
-            self._md_ref = md
+    def __init__(self, md: Markdown) -> None:  # noqa: D107
+        self._md_ref: Markdown = md
 
     def convert(self, text: str, stash: dict[str, str] | None = None) -> Markup:
         """Convert Markdown text to safe HTML.
@@ -161,18 +160,15 @@ class _MarkdownConverter:
         Returns:
             Safe HTML.
         """
-        # store current md instance
-        md = self._md
-        self._level += 1
+        md = _mimic(self._md_ref)
 
         # prepare for conversion
-        md.treeprocessors[_IdPrependingTreeprocessor.name].id_prefix = f"exec-{self._counter}--"
-        self._counter += 1
+        md.treeprocessors[_IdPrependingTreeprocessor.name].id_prefix = f"exec-{MarkdownConverter.counter}--"
+        MarkdownConverter.counter += 1
 
         try:  # noqa: WPS501
             converted = md.convert(text)
         finally:
-            self._level -= 1
             md.treeprocessors[_IdPrependingTreeprocessor.name].id_prefix = ""
 
         # restore html from stash
@@ -180,15 +176,3 @@ class _MarkdownConverter:
             converted = converted.replace(placeholder, stashed)
 
         return Markup(converted)
-
-    @property
-    def _md(self) -> Markdown:
-        try:
-            return self._md_stack[self._level]
-        except IndexError:
-            self._md_stack.append(_mimic(self._md_ref))
-            return self._md
-
-
-# provide a singleton
-markdown = _MarkdownConverter()
