@@ -13,7 +13,13 @@ def test_no_p_around_html(md: Markdown) -> None:
         md: A Markdown instance (fixture).
     """
     code = "<pre><code>hello</code></pre>"
-    html = base_format("whatever", lambda _: _, code, md, id="", html=True, source="", result="", tabs=("", ""))
+    html = base_format(
+        language="whatever",
+        run=lambda code, **_: code,
+        code=code,
+        md=md,
+        html=True,
+    )
     assert html == code
 
 
@@ -25,5 +31,12 @@ def test_render_source(md: Markdown, html: bool) -> None:
         md: A Markdown instance (fixture).
         html: Whether output is HTML or not.
     """
-    markup = base_format("python", lambda _: _, "hello", md, html, "tabbed-left", "", ("Source", "Output"), id="")
+    markup = base_format(
+        language="python",
+        run=lambda code, **_: code,
+        code="hello",
+        md=md,
+        html=html,
+        source="tabbed-left",
+    )
     assert "Source" in markup
