@@ -58,4 +58,25 @@ def test_error_raised(md: Markdown, caplog) -> None:
         )
     )
     assert "error" in html
-    assert "Execution of sh code block exited with non-zero status" in caplog.text
+    assert "Execution of sh code block exited with unexpected code 2" in caplog.text
+
+
+def test_return_code(md: Markdown, caplog) -> None:
+    """Assert return code is used correctly.
+
+    Parameters:
+        md: A Markdown instance (fixture).
+        caplog: Pytest fixture to capture logs.
+    """
+    html = md.convert(
+        dedent(
+            """
+            ```sh exec="yes" returncode="1"
+            echo Not in the mood
+            exit 1
+            ```
+            """
+        )
+    )
+    assert "Not in the mood" in html
+    assert "exited with" not in caplog.text
